diff src/org/tmatesoft/hg/core/LogCommand.java @ 74:6f1b88693d48

Complete refactoring to org.tmatesoft
author Artem Tikhomirov <tikhomirov.artem@gmail.com>
date Mon, 24 Jan 2011 03:14:45 +0100
parents 993f6f8e1314
children c677e1593919
line wrap: on
line diff
--- a/src/org/tmatesoft/hg/core/LogCommand.java	Sun Jan 23 04:06:18 2011 +0100
+++ b/src/org/tmatesoft/hg/core/LogCommand.java	Mon Jan 24 03:14:45 2011 +0100
@@ -16,7 +16,7 @@
  */
 package org.tmatesoft.hg.core;
 
-import static com.tmate.hgkit.ll.HgRepository.TIP;
+import static org.tmatesoft.hg.repo.HgRepository.TIP;
 
 import java.util.Calendar;
 import java.util.Collections;
@@ -26,12 +26,11 @@
 import java.util.Set;
 import java.util.TreeSet;
 
+import org.tmatesoft.hg.repo.Changeset;
+import org.tmatesoft.hg.repo.HgRepository;
+import org.tmatesoft.hg.repo.StatusCollector;
 import org.tmatesoft.hg.util.PathPool;
 
-import com.tmate.hgkit.ll.Changeset;
-import com.tmate.hgkit.ll.HgRepository;
-import com.tmate.hgkit.ll.Nodeid;
-import com.tmate.hgkit.ll.StatusCollector;
 
 /**
  * <pre>
@@ -137,7 +136,7 @@
 	}
 
 	/**
 	 * Similar to {@link #execute(com.tmate.hgkit.ll.Changeset.Inspector)}, collects and return result as a list.
 	 */
 	public List<Cset> execute() {
 		CollectHandler collector = new CollectHandler();
@@ -137,7 +136,7 @@
 
 	/**
-	 * Similar to {@link #execute(com.tmate.hgkit.ll.Changeset.Inspector)}, collects and return result as a list.
+	 * Similar to {@link #execute(org.tmatesoft.hg.repo.Changeset.Inspector)}, collects and return result as a list.
 	 */
 	public List<Cset> execute() {